pub struct CustomField {
pub name: Option<String>,
pub value: Option<String>,
}Expand description
Custom fields. These can be used to create a counter with arbitrary field/value pairs. See: go/rpcsp-custom-fields.
This type is not used in any activity, and only used as part of another schema.
Fields
name: Option<String>Name is the field name.
value: Option<String>Value is the field value. It is important that in contrast to the CounterOptions.field, the value here is a constant that is not derived from the IAMContext.